pub trait CheckSpirvStruct {
// Required method
fn check_spirv_layout(name: &str, spirv: Vec<u32>);
}Expand description
Trait for structs that should have their layout checked against a SPIRV type
Required Methods
Sourcefn check_spirv_layout(name: &str, spirv: Vec<u32>)
fn check_spirv_layout(name: &str, spirv: Vec<u32>)
Check this struct against the named instance in the given spirv
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".